@@ -1,8 +1,8 @@
 """Top-level package for SCATrEx."""
 
 __author__ = """Pedro Fale Ferreira"""
-__email__ = 'pedro.miguel.ferreira.pf@gmail.com'
-__version__ = '0.0.3'
+__email__ = "pedro.miguel.ferreira.pf@gmail.com"
+__version__ = "0.0.3"
 
 from .scatrex import SCATrEx
 from .models import *
